@@ -1,7 +1,6 @@
 import itertools
 import re
 import unicodedata
-import pyjf3
 import kaa
 from kaa.command import Commands, command, is_enable, norec, norerun
 from kaa import document
@@ -707,7 +706,7 @@ class EditCommands(Commands):
     @command('edit.undo')
     @norerun
     def undo(self, wnd):
-        if wnd.document.undo.can_undo():
+        if wnd.document.undo and wnd.document.undo.can_undo():
             wnd.screen.selection.clear()
             pos = None
             for rec in wnd.document.undo.undo():
@@ -738,7 +737,7 @@ class EditCommands(Commands):
     @command('edit.redo')
     @norerun
     def redo(self, wnd):
-        if wnd.document.undo.can_redo():
+        if wnd.document.undo and wnd.document.undo.can_redo():
             wnd.screen.selection.clear()
             pos = None
             for rec in wnd.document.undo.redo():
@@ -819,6 +818,7 @@ class EditCommands(Commands):
 
     @command('edit.conv.full-width')
     def conv_fullwidth(self, wnd):
+        import pyjf3
         s = self._get_sel(wnd)
         if s:
             self.put_string(wnd, pyjf3.tofull(s))
