@@ -6,11 +6,33 @@ from kaa.filetype.default import defaultmode
 from kaa import consts
 
 class FileStorage:
+    def adjust_encoding(self, encoding):
+        if encoding.lower() == 'shiftjis':
+            return 'cp932'
+        return encoding
+        
+    def guess_japanese_encoding(self, filename):
+        import pyjf3
+        ret = pyjf3.guess(open(filename, 'rb').read())
+        
+        if ret in (pyjf3.ASCII, pyjf3.UTF8):
+            return 'utf-8'
+        elif ret == pyjf3.SJIS:
+            return 'cp932'
+        elif ret == pyjf3.EUC:
+            return 'euc-jp'
+        elif ret == pyjf3.JIS:
+            return 'iso-2022-jp'
+        elif ret == pyjf3.UTF16_LE:
+            return 'utf-16le'
+        elif ret == pyjf3.UTF16_BE:
+            return 'utf-16be'
+        
     def get_textio(self, fileinfo, filemustexists=False):
         try:
             # use surrogateescape to preserve file contents intact.
             textio = open(fileinfo.fullpathname, 'r',
-                        encoding=fileinfo.encoding, 
+                        encoding=self.adjust_encoding(fileinfo.encoding), 
                         errors='surrogateescape', 
                         newline=fileinfo.nlchars)
         
@@ -98,7 +120,8 @@ class FileStorage:
             if doc.fileinfo.newline is None:
                 doc.fileinfo.newline = kaa.app.config.DEFAULT_NEWLINE
 
-        with open(filename, 'w', encoding=doc.fileinfo.encoding,
+        with open(filename, 'w', 
+                 encoding=self.adjust_encoding(doc.fileinfo.encoding),
                  newline=consts.NEWLINE_CHARS[doc.fileinfo.newline],
                  errors='surrogateescape') as f:
 
