@@ -7,10 +7,11 @@ from kaa.command import Commands, command, norec, norerun
 from kaa.keyboard import *
 
 PythonThemes = {
-    'default':
+    'basic':
         Theme([
             Style('python-bytes', 'blue', 'default'),
-        ])
+        ]),
+
 }
 
 PYTHONMENU = [
