@@ -14,11 +14,11 @@ pythonconsole_keys = {
 }
 
 PythonConsoleThemes = {
-    'default':
+    'basic':
         Theme([
             Style('stdout', 'Default', 'Default'),
             Style('stderr', 'Magenta', 'Default'),
-        ])
+        ]),
 }
 
 class PythonConsoleMode(pythonmode.PythonMode):
